#-*- encoding: utf-8 -*-

'''
Created on 2014.04.21

global constant here

@author: Allen
'''




